@@ -11,13 +11,14 @@ import argparse
 import logging
 import sys
 import traceback
+import os
 
 _CREDIT_LINE = "Powered by microbuild - A Lightweight Python Build Tool."
-_LOGGING_FORMAT = "[ %(message)s ]"
+_LOGGING_FORMAT = "[ %(name)s - %(message)s ]"
     
 def build(module,args):
     """
-    Build the specified module.
+    Build the specified module with specified arguments.
     
     @type module: module
     @type args: list of arguments
@@ -33,10 +34,14 @@ def build(module,args):
     _run_from_task_name(module,args.task)
     
 def _run_from_task_name(module,task_name):
+    """
+    @type module: module
+    @type task_name: string
+    @param task_name: Task name, exactly corresponds to function name.
+    """
 
     # Create logger.
-    logging.basicConfig(level=logging.INFO,format=_LOGGING_FORMAT)
-    logger = logging.getLogger(module.__name__)
+    logger = _get_logger(module)
     
     task = getattr(module,task_name)
     _run(module,logger,task,set([]))
@@ -59,24 +64,34 @@ def _run(module,logger,task,completed_tasks):
     # Perform current task, if need to.
     if task not in completed_tasks:
 
-        logging.info("Starting task \"%s\"" % task.__name__)
-
-        try:
-            # Run task.
-            task()
-        except:
-            logging.critical("Error in task \"%s\"" % task.__name__)
-            traceback.print_exc()
-            logging.critical("Build aborted")
-            sys.exit()
+        if task.is_ignorable():
         
-        logging.info("Completed task \"%s\"" % task.__name__)
+            logger.info("Ignoring task \"%s\"" % task.__name__)
+            
+        else:
+
+            logger.info("Starting task \"%s\"" % task.__name__)
+
+            try:
+                # Run task.
+                task()
+            except:
+                logger.critical("Error in task \"%s\"" % task.__name__)
+                traceback.print_exc()
+                logger.critical("Build aborted")
+                sys.exit()
+            
+            logger.info("Completed task \"%s\"" % task.__name__)
         
         completed_tasks.add(task)
     
     return completed_tasks
 
 def _create_parser(module):
+    """
+    @type module: module
+    @rtype: argparse.ArgumentParser
+    """
 
     # Get all tasks.
     tasks = _get_tasks(module)
@@ -164,6 +179,15 @@ class _TaskDecorator(object):
         
 # Abbreviate for convenience.
 task = _TaskDecorator
+
+def ignore(obj):
+    """
+    Decorator to specify that a task should be ignored.
+    
+    @type obj: function or Task, depending on order @ignore and @task used
+    """
+    obj.ignorable = True
+    return obj
         
 class Task(object):
     
@@ -186,10 +210,18 @@ class Task(object):
         Returns true is an object is a build task.
         """
         return isinstance(obj,cls)
+        
+    def is_ignorable(self):
+        """
+        Returns true if task can be ignored.
+        """
+        return ( hasattr(self,'ignorable') and self.ignorable == True ) or ( hasattr(self.func,'ignorable') and self.func.ignorable == True )
     
 def _get_tasks(module):
     """
     Returns all functions marked as tasks.
+    
+    @type module: module
     """
     # Get all functions that are marked as task and pull out the task object
     # from each (name,value) pair.
@@ -198,5 +230,32 @@ def _get_tasks(module):
 def _get_max_name_length(module):
     """
     Returns the length of the longest task name.
+    
+    @type module: module
     """
     return max([len(task.__name__) for task in _get_tasks(module)])
+    
+def _get_logger(module):
+    """
+    @type module: module
+    @rtype: logging.Logger
+    """
+
+    # Create Logger
+    logger = logging.getLogger(os.path.basename(module.__file__))
+    logger.setLevel(logging.DEBUG)
+
+    # Create console handler and set level to debug
+    ch = logging.StreamHandler()
+    ch.setLevel(logging.DEBUG)
+
+    # Create formatter
+    formatter = logging.Formatter(_LOGGING_FORMAT)
+
+    # Add formatter to ch
+    ch.setFormatter(formatter)
+
+    # Add ch to logger
+    logger.addHandler(ch)
+
+    return logger
